@@ -8,14 +8,14 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: JParameter.php 3047 2010-04-21 04:08:16Z fishbone $
+ * @version    SVN: $Id: JParameter.php 3966 2011-01-26 07:53:26Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($this->gEnv->getJoomlaRootPath() . '/class/object.php');
 require_once($this->gEnv->getJoomlaRootPath() . '/class/registry.php');
-//class JParameter
+
 class JParameter extends JRegistry
 {
 	private $params = array();
@@ -43,11 +43,12 @@ class JParameter extends JRegistry
 	 *
 	 * @param string $key		取得キー
 	 * @param string			設定値
-	 * @return 					なし
+	 * @return 					設定値
 	 */
 	public function set($key, $value)
 	{
 		$this->params[$key] = $value;
+		return $value;
 	}
 	/**
 	 * キーを指定して値を取得
@@ -59,6 +60,21 @@ class JParameter extends JRegistry
 	{
 		return isset($this->params[$key]) ? $this->params[$key] : '';
 	}
+	/**
+	 * デフォルト値を設定して値を取得
+	 *
+	 * @param string $key		取得キー
+	 * @param string $default	デフォルト値
+	 * @return string			取得値
+	 */
+	public function def($key, $default = '')
+	{
+		// 値が設定されていなければデフォルト値を設定
+		$this->params[$key] = $default;
+		
+		$value = $this->get($key);
+		return $value;
+	}
 }
 class JUser
 {
