@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 3933 2011-01-12 00:51:45Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 4140 2011-05-16 14:21:08Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -151,6 +151,9 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 						$task = 'pageinfo';			// ページ情報をデフォルトにする
 					} else if ($task == 'userlist_detail'){		// ユーザ詳細
 						$task = 'userlist';
+					} else if ($task == 'loginstatus' ||				// ログイン状況
+								$task == 'loginstatus_history'){		// ログイン状況ユーザ単位履歴
+						$task = 'loginstatus';
 					} else if ($task == 'pagedef_detail' ||		// ページ定義詳細
 								$task == 'pagedef_mobile' ||	// 携帯用ページ定義
 								$task == 'pagedef_smartphone'){		// スマートフォン用ページ定義
