@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_analyzeDb.php 3878 2010-12-04 02:14:23Z fishbone $
+ * @version    SVN: $Id: admin_analyzeDb.php 4159 2011-05-31 14:49:36Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -487,5 +487,140 @@ class admin_analyzeDb extends BaseDb
 		$destStr = substr($str, 0, $len) . $addStr;
 		return $destStr;
 	}
+	/**
+	 * 日付範囲内のURL単位ページビュー数を取得
+	 *
+	 * @param string	$path		アクセスポイント(NULL=すべてのデータ)
+	 * @param date		$startDate	集計期間、開始日(NULL=先頭からすべて)
+	 * @param date		$endDate	集計期間、終了日
+	 * @param int		$limit		取得する項目数
+	 * @param int		$page		取得するページ(1～)
+	 * @param function $callback	コールバック関数
+	 * @return						なし
+	 */
+	function getUrlListByPageView($path, $startDate, $endDate, $limit, $page, $callback)
+	{
+		$offset = $limit * ($page -1);
+		if ($offset < 0) $offset = 0;
+		
+		$params = array();
+		$queryStr  = 'SELECT SUM(ap_count) AS total, ap_url AS url FROM _analyze_page_view ';
+		$queryStr .=   'WHERE ap_type = ? '; $params[] = 0;
+		if (is_null($startDate)){
+			$queryStr .=     'AND ap_date <= ? ';
+		} else {
+			$queryStr .=     'AND (? <= ap_date AND ap_date <= ?) ';
+			$params[] = $startDate;
+		}
+		$params[] = $endDate;
+		if (!is_null($path)){
+			$queryStr .=  'AND ap_path = ? ';
+			$params[] = $path;
+		}
+		$queryStr .=  'GROUP BY url ';
+		$queryStr .=  'ORDER BY total DESC limit ' . $limit . ' offset ' . $offset;
+		$this->selectLoop($queryStr, $params, $callback);
+	}
+	/**
+	 * 日付範囲内のURL単位ページビュー数用のURL数を取得
+	 *
+	 * @param string	$path		アクセスポイント(NULL=すべてのデータ)
+	 * @param date		$startDate	集計期間、開始日(NULL=先頭からすべて)
+	 * @param date		$endDate	集計期間、終了日
+	 * @return int						総数
+	 */
+	function getUrlListCountByPageView($path, $startDate, $endDate)
+	{
+		$params = array();
+		$queryStr  = 'SELECT SUM(ap_count) AS total, ap_url AS url FROM _analyze_page_view ';
+		$queryStr .=   'WHERE ap_type = ? '; $params[] = 0;
+		if (is_null($startDate)){
+			$queryStr .=     'AND ap_date <= ? ';
+		} else {
+			$queryStr .=     'AND (? <= ap_date AND ap_date <= ?) ';
+			$params[] = $startDate;
+		}
+		$params[] = $endDate;
+		if (!is_null($path)){
+			$queryStr .=  'AND ap_path = ? ';
+			$params[] = $path;
+		}
+		$queryStr .=  'GROUP BY url ';
+		return $this->selectRecordCount($queryStr, $params);
+	}
+	/**
+	 * 日付範囲内のURL単位訪問数、訪問者数を取得
+	 *
+	 * @param int       $type		データのタイプ(0=訪問数、1=訪問者数)
+	 * @param string	$path		アクセスポイント(NULL=すべてのデータ)
+	 * @param date		$startDate	集計期間、開始日(NULL=先頭からすべて)
+	 * @param date		$endDate	集計期間、終了日
+	 * @param int		$limit		取得する項目数
+	 * @param int		$page		取得するページ(1～)
+	 * @param function $callback	コールバック関数
+	 * @return						なし
+	 */
+	function getUrlListByDailyCount($type, $path, $startDate, $endDate, $limit, $page, $callback)
+	{
+		$offset = $limit * ($page -1);
+		if ($offset < 0) $offset = 0;
+		
+		$params = array();
+		$queryStr  = 'SELECT aa_count AS total, aa_url AS url FROM _analyze_daily_count ';
+		$queryStr .=   'WHERE aa_type = ? '; $params[] = $type;
+		$queryStr .=     'AND aa_url != ? '; $params[] = '';			/*アクセスポイントごとの集計値以外*/
+		if (is_null($startDate)){
+			$queryStr .=     'AND aa_date <= ? ';
+		} else {
+			$queryStr .=     'AND (? <= aa_date AND aa_date <= ?) ';
+			$params[] = $startDate;
+		}
+		$params[] = $endDate;
+		if (is_null($path)){		// すべてのアクセスポイントの場合
+			$queryStr .=  'AND aa_path = ? ';
+			$params[] = '';
+		} else {
+			$queryStr .=  'AND aa_path = ? ';
+			$params[] = $path;
+		}
+		$queryStr .=  'GROUP BY url ';
+		$queryStr .=  'ORDER BY total DESC limit ' . $limit . ' offset ' . $offset;
+		$this->selectLoop($queryStr, $params, $callback);
+	}
+	/**
+	 * 日付範囲内のURL単位訪問数、訪問者数用のURL数を取得
+	 *
+	 * @param int       $type		データのタイプ(0=訪問数、1=訪問者数)
+	 * @param string	$path		アクセスポイント(NULL=すべてのデータ)
+	 * @param date		$startDate	集計期間、開始日(NULL=先頭からすべて)
+	 * @param date		$endDate	集計期間、終了日
+	 * @param int		$limit		取得する項目数
+	 * @param int		$page		取得するページ(1～)
+	 * @param function $callback	コールバック関数
+	 * @return						なし
+	 */
+	function getUrlListCountByDailyCount($type, $path, $startDate, $endDate)
+	{
+		$params = array();
+		$queryStr  = 'SELECT aa_count AS total, aa_url AS url FROM _analyze_daily_count ';
+		$queryStr .=   'WHERE aa_type = ? '; $params[] = $type;
+		$queryStr .=     'AND aa_url != ? '; $params[] = '';			/*アクセスポイントごとの集計値以外*/
+		if (is_null($startDate)){
+			$queryStr .=     'AND aa_date <= ? ';
+		} else {
+			$queryStr .=     'AND (? <= aa_date AND aa_date <= ?) ';
+			$params[] = $startDate;
+		}
+		$params[] = $endDate;
+		if (is_null($path)){		// すべてのアクセスポイントの場合
+			$queryStr .=  'AND aa_path = ? ';
+			$params[] = '';
+		} else {
+			$queryStr .=  'AND aa_path = ? ';
+			$params[] = $path;
+		}
+		$queryStr .=  'GROUP BY url ';
+		return $this->selectRecordCount($queryStr, $params);
+	}
 }
 ?>
