@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainDb.php 3666 2010-10-04 07:36:04Z fishbone $
+ * @version    SVN: $Id: blog_mainDb.php 3908 2010-12-28 03:23:56Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -372,6 +372,7 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_show_comment, ';
 		$queryStr .=   'be_receive_comment, ';
 		$queryStr .=   'be_blog_id, ';
+		$queryStr .=   'be_dt, ';
 		$queryStr .=   'be_regist_user_id, ';
 		$queryStr .=   'be_regist_dt, ';
 		$queryStr .=   'be_active_start_dt, ';
@@ -379,9 +380,9 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_create_user_id, ';
 		$queryStr .=   'be_create_dt) ';
 		$queryStr .= 'VALUES ';
-		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
 		$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $name, $html, $html2, $status, 
-												intval($showComment), intval($receiveComment), $blogId, $regUserId, $regDt, $startDt, $endDt, $userId, $now));
+												intval($showComment), intval($receiveComment), $blogId, $now, $regUserId, $regDt, $startDt, $endDt, $userId, $now));
 		
 		// 新規のシリアル番号取得
 		$newSerial = 0;
@@ -478,6 +479,7 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_show_comment, ';
 		$queryStr .=   'be_receive_comment, ';
 		$queryStr .=   'be_blog_id, ';
+		$queryStr .=   'be_dt, ';
 		$queryStr .=   'be_regist_user_id, ';
 		$queryStr .=   'be_regist_dt, ';
 		$queryStr .=   'be_active_start_dt, ';
@@ -485,9 +487,9 @@ class blog_mainDb extends BaseDb
 		$queryStr .=   'be_create_user_id, ';
 		$queryStr .=   'be_create_dt) ';
 		$queryStr .= 'VALUES ';
-		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$queryStr .=   '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
 		$this->execStatement($queryStr, array($entryId, $langId, $historyIndex, $name, $html, $html2, $status, 
-												intval($showComment), intval($receiveComment), $blogId, $rUserId, $rDt, $startDt, $endDt, $userId, $now));
+												intval($showComment), intval($receiveComment), $blogId, $now, $rUserId, $rDt, $startDt, $endDt, $userId, $now));
 
 		// 新規のシリアル番号取得
 		$newSerial = 0;
@@ -508,6 +510,49 @@ class blog_mainDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * 記事更新日の更新
+	 *
+	 * @param string  $id			エントリーID
+	 * @param string  $langId		言語ID
+	 * @return bool					true = 成功、false = 失敗
+	 */
+	function updateEntryDt($id, $langId)
+	{
+		$serial = $this->getEntrySerialNoByContentId($id, $langId);
+		if (empty($serial)) return false;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
+						
+		// トランザクション開始
+		$this->startTransaction();
+		
+		// 指定のシリアルNoのレコードが削除状態でないかチェック
+		$queryStr  = 'SELECT * FROM blog_entry ';
+		$queryStr .=   'WHERE be_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		if ($ret){		// 既に登録レコードがあるとき
+			if ($row['be_deleted']){		// レコードが削除されていれば終了
+				$this->endTransaction();
+				return false;
+			}
+		} else {		// 存在しない場合は終了
+			$this->endTransaction();
+			return false;
+		}
+		// 日付を更新
+		$queryStr  = 'UPDATE blog_entry ';
+		$queryStr .=   'SET be_dt = ?, ';	// 更新日
+		$queryStr .=     'be_update_user_id = ?, ';
+		$queryStr .=     'be_update_dt = ? ';
+		$queryStr .=   'WHERE be_serial = ?';
+		$this->execStatement($queryStr, array($now, $userId, $now, $serial));
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * 記事カテゴリーの更新
 	 *
