@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_new_boxWidgetContainer.php 3455 2010-08-06 02:58:01Z fishbone $
+ * @version    SVN: $Id: blog_new_boxWidgetContainer.php 3917 2011-01-01 03:20:13Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -24,6 +24,7 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 	private $isEntry;	// 記事の投稿があるかどうか
 	private $defaultUrl;	// システムのデフォルトURL
 	private $headRssFile;				// RSS情報
+	private $optionPassage;						// 表示オプション(経過日時)
 	const DEFAULT_ITEM_COUNT = 20;		// デフォルトの表示項目数
 	const MAX_TITLE_LENGTH = 20;			// タイトルの最大文字列長
 	const DEFAULT_TITLE = 'ブログ最新記事';		// デフォルトのウィジェットタイトル名
@@ -71,11 +72,14 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 		// 設定値を取得
 		$itemCount = self::DEFAULT_ITEM_COUNT;	// 表示項目数
 		$useRss = 1;							// RSS配信を行うかどうか
+		$this->optionPassage = 0;						// 表示オプション(経過日時)
 		$paramObj = $this->getWidgetParamObj();
 		if (!empty($paramObj)){
 			$itemCount	= $paramObj->itemCount;
 			$useRss		= $paramObj->useRss;// RSS配信を行うかどうか
 			if (!isset($useRss)) $useRss = 1;
+			$this->optionPassage	= $paramObj->optionPassage;		// 表示オプション(経過日時)
+			if (!isset($this->optionPassage)) $this->optionPassage = 0;
 		}
 		
 		// 新規ブログタイトルを取得
@@ -154,9 +158,20 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 		// 記事へのリンク
 		$url = $this->defaultUrl . '?'. M3_REQUEST_PARAM_BLOG_ENTRY_ID . '=' . $fetchedRow['be_id'];
 
+		// オプション項目
+		$optionStr = '';
+		if ($this->optionPassage){
+			$time = strtotime($fetchedRow['be_regist_dt']);
+			if ($time != strtotime($this->gEnv->getInitValueOfTimestamp())){
+				$time = time() - $time;
+				$optionStr = '<div style="text-align:right;font-size:smaller;">' . $this->convertToDispString($this->convertToDispPassageTime($time) . '前') . '</div>';
+			}
+		}
+		
 		$row = array(
 			'link_url' => $this->convertUrlToHtmlEntity($this->getUrl($url, true/*リンク用*/)),		// リンク
-			'name' => $this->convertToDispString($title)			// タイトル
+			'name' => $this->convertToDispString($title),			// タイトル
+			'option'	=> $optionStr								// オプション項目
 		);
 		$this->tmpl->addVars('itemlist', $row);
 		$this->tmpl->parseTemplate('itemlist', 'a');
