@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_login_boxWidgetContainer.php 1350 2008-12-14 09:35:06Z fishbone $
+ * @version    SVN: $Id: ec_login_boxWidgetContainer.php 2256 2009-08-26 15:00:05Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -22,22 +22,21 @@ class ec_login_boxWidgetContainer extends BaseWidgetContainer
 	const TARGET_WIDGET = 'ec_main';		// 呼び出しウィジェットID
 	const MAIL_OBJ_ID = 'ecmail';			// メール連携オブジェクト
 	const EC_LIB_ID = "eclib";		// EC共通ライブラリオブジェクトID
+	const DEFAULT_TITLE = '会員ログイン';
 	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DB接続オブジェクト作成
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
 		
 		// メール連携オブジェクト取得
-		$this->ecMailObj = $gInstanceManager->getObject(self::MAIL_OBJ_ID);
+		$this->ecMailObj = $this->gInstance->getObject(self::MAIL_OBJ_ID);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -64,12 +63,6 @@ class ec_login_boxWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gDesignManager;
-		global $gAccessManager;
-		global $gPageManager;
-		global $gInstanceManager;
-		
 		$act = $request->trimValueOf('act');
 		if ($act == 'ecloginbox_login'){			// 会員ログインのとき
 			// アカウント、パスワード取得
@@ -77,11 +70,11 @@ class ec_login_boxWidgetContainer extends BaseWidgetContainer
 			$password = $request->trimValueOf('password');
 		
 			// ユーザ認証
-			if ($gAccessManager->userLoginByAccount($account, $password)){
+			if ($this->gAccess->userLoginByAccount($account, $password)){
 				// 初回ログインのときは、仮会員を正会員にする
-				$userId = $gEnvManager->getCurrentUserId();
+				$userId = $this->gEnv->getCurrentUserId();
 				if ($userId != 0){
-					$ret = $gInstanceManager->getObject(self::EC_LIB_ID)->makeTmpMemberToProperMember($userId);
+					$ret = $this->gInstance->getObject(self::EC_LIB_ID)->makeTmpMemberToProperMember($userId);
 					if ($ret){
 						$ret = $this->sysDb->makeNormalLoginUser($userId);// 一般ログインユーザに設定
 						
@@ -90,24 +83,24 @@ class ec_login_boxWidgetContainer extends BaseWidgetContainer
 					}
 				}
 				// 画面を全体を再表示する
-				$gPageManager->redirect($gEnvManager->getCurrentRequestUri());
+				$this->gPage->redirect($this->gEnv->getCurrentRequestUri());
 				return;
 			} else {
 				// ログイン状態を削除
-				$gAccessManager->userLogout();
+				$this->gAccess->userLogout();
 				
 				$this->tmpl->setAttribute('login_status', 'visibility', 'visible');		// ログイン状況
 				$this->tmpl->addVar("login_status", "message", 'ログインに失敗しました');
 			}
 		} else if ($act == 'ecloginbox_logout'){			// 会員ログアウトのとき
-			$gAccessManager->userLogout();
+			$this->gAccess->userLogout();
 			
 			// 画面を全体を再表示する
-			$gPageManager->redirect($gEnvManager->getCurrentRequestUri());
+			$this->gPage->redirect($this->gEnv->getCurrentRequestUri());
 			return;
 		}
 		// ログイン状態を取得
-		$userName = $gEnvManager->getCurrentUserName();
+		$userName = $this->gEnv->getCurrentUserName();
 		if (empty($userName)){		// ユーザがログインしていないとき
 			// ログイン入力部、ログインボタン表示
 			$this->tmpl->setAttribute('login_field', 'visibility', 'visible');
@@ -122,31 +115,36 @@ class ec_login_boxWidgetContainer extends BaseWidgetContainer
 			$this->tmpl->setAttribute('member_button', 'visibility', 'visible');
 		}
 		
-		// タイトル部のパラメータ
-		$this->tmpl->addVar("_widget", "default_menu_param", $gDesignManager->getDefaultWidgetTableParam());
-		
-		// ディレクトリを設定
-		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());
-		
 		// パスワード送信画面へのリンク
 		$sendpwdUrl = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'task=sendpwd');
-		$this->tmpl->addVar("regmember_button", "sendpwd_url", $sendpwdUrl);
+		$this->tmpl->addVar("regmember_button", "sendpwd_url", $this->getUrl($sendpwdUrl, true));
 		
 		// 会員登録画面へのリンク
 		$regMemberUrl = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'task=regmember');
-		$this->tmpl->addVar("regmember_button", "regmember_url", $regMemberUrl);
+		$this->tmpl->addVar("regmember_button", "regmember_url", $this->getUrl($regMemberUrl, true));
 		
 		// パスワード変更画面へのリンク
 		$changepwdUrl = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'task=changepwd');
-		$this->tmpl->addVar("member_button", "changepwd_url", $changepwdUrl);
+		$this->tmpl->addVar("member_button", "changepwd_url", $this->getUrl($changepwdUrl, true));
 		
 		// 会員情報画面へのリンク
 		$memberUrl = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'task=member');
-		$this->tmpl->addVar("member_button", "member_url", $memberUrl);
+		$this->tmpl->addVar("member_button", "member_url", $this->getUrl($memberUrl, true));
 		
 		// 注文履歴画面へのリンク
 		$historyUrl = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'task=orderhistory');
-		$this->tmpl->addVar("member_button", "orderhistory_url", $historyUrl);
+		$this->tmpl->addVar("member_button", "orderhistory_url", $this->getUrl($historyUrl, true));
+	}
+	/**
+	 * ウィジェットのタイトルを設定
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
+	 * @return string 						ウィジェットのタイトル名
+	 */
+	function _setTitle($request, &$param)
+	{
+		return self::DEFAULT_TITLE;
 	}
 }
 ?>
