@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainOtherWidgetContainer.php 1560 2009-03-09 09:39:21Z fishbone $
+ * @version    SVN: $Id: admin_ec_mainOtherWidgetContainer.php 2094 2009-07-11 11:27:23Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -22,7 +22,6 @@ class admin_ec_mainOtherWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	const USE_EMAIL		= 'use_email';		// EMAIL機能が使用可能かどうか
 	const AUTO_EMAIL_SENDER	= 'auto_email_sender';		// 自動送信メール用送信者アドレス
 	const DEFAULT_CURRENCY	= 'default_currency';				// デフォルト通貨
-	const DISP_PRODUCT_COUNT	= 'disp_product_count';		// 商品一覧の商品表示数
 	const CF_PERMIT_NON_MEMBER_ORDER = 'permit_non_member_order';			// 非会員の購入許可
 			
 	/**
@@ -61,23 +60,18 @@ class admin_ec_mainOtherWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		
-		$defaultLang	= $gEnvManager->getDefaultLanguage();
-		
+		$defaultLang	= $this->gEnv->getDefaultLanguage();
 		$act = $request->trimValueOf('act');
 		
 		$this->defaultCurrency = $request->trimValueOf('currency');			// デフォルト通貨
 		$useEmail = ($request->trimValueOf('use_email') == 'on') ? 1 : 0;		// EMAIL機能が使用可能かどうか
 		$autoEmailSender = $request->trimValueOf('auto_email');						// 自動送信メールの送信元アドレス
-		$productCount = $request->trimValueOf('product_list_count');						// 商品表示数
 		$nonMemberOrder = ($request->trimValueOf('non_member_order') == 'on') ? 1 : 0;		// 非会員からの注文を許可するかどうか
 		
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
 			$this->checkInput($this->defaultCurrency, 'デフォルト通貨');
 			$this->checkMailAddress($autoEmailSender, '自動送信メールの送信元メールアドレス');
-			$this->checkNumeric($productCount, '表示項目数');
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				$isErr = false;
@@ -91,9 +85,6 @@ class admin_ec_mainOtherWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				if (!$isErr){
 					if (!$this->db->updateConfig(self::AUTO_EMAIL_SENDER, $autoEmailSender)) $isErr = true;
 				}
-				if (!$isErr){
-					if (!$this->db->updateConfig(self::DISP_PRODUCT_COUNT, $productCount)) $isErr = true;// 商品一覧の商品表示数
-				}
 				if (!$isErr){
 					if (!$this->db->updateConfig(self::CF_PERMIT_NON_MEMBER_ORDER, $nonMemberOrder)) $isErr = true;// 非会員からの注文受付
 				}
@@ -102,14 +93,12 @@ class admin_ec_mainOtherWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$this->defaultCurrency = $this->db->getConfig(self::DEFAULT_CURRENCY);		// デフォルト通貨
 				$useEmail	= $this->db->getConfig(self::USE_EMAIL);
 				$autoEmailSender	= $this->db->getConfig(self::AUTO_EMAIL_SENDER);
-				$productCount = $this->db->getConfig(self::DISP_PRODUCT_COUNT);						// 商品一覧の商品表示数
 				$nonMemberOrder = $this->db->getConfig(self::CF_PERMIT_NON_MEMBER_ORDER);			// 非会員からの注文受付
 			}
 		} else {		// 初期表示の場合
 			$this->defaultCurrency = $this->db->getConfig(self::DEFAULT_CURRENCY);		// デフォルト通貨
 			$useEmail	= $this->db->getConfig(self::USE_EMAIL);
 			$autoEmailSender	= $this->db->getConfig(self::AUTO_EMAIL_SENDER);
-			$productCount = $this->db->getConfig(self::DISP_PRODUCT_COUNT);						// 商品一覧の商品表示数
 			$nonMemberOrder = $this->db->getConfig(self::CF_PERMIT_NON_MEMBER_ORDER);			// 非会員からの注文受付
 		}
 		// 画面に書き戻す
@@ -117,7 +106,6 @@ class admin_ec_mainOtherWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		if ($useEmail) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "use_email", $checked);
 		$this->tmpl->addVar("_widget", "auto_email", $autoEmailSender);
-		$this->tmpl->addVar("_widget", "product_list_count", $productCount);		// 商品一覧の商品表示数
 		$checked = '';
 		if (!empty($nonMemberOrder)) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "non_member_order", $checked);			// 非会員からの注文受付
@@ -135,8 +123,6 @@ class admin_ec_mainOtherWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function currencyLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-		
 		$selected = '';
 		if ($fetchedRow['cu_id'] == $this->defaultCurrency){
 			$selected = 'selected';
