@@ -10,14 +10,16 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m_chachaMypageWidgetContainer.php 3355 2010-07-08 10:34:55Z fishbone $
+ * @version    SVN: $Id: m_chachaMypageWidgetContainer.php 3363 2010-07-10 05:12:31Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/m_chachaBaseWidgetContainer.php');
 
 class m_chachaMypageWidgetContainer extends m_chachaBaseWidgetContainer
 {
+	private $messageCount;		// 表示メッセージ数
 	private $isExistsMessage;	// メッセージが存在するかどうか
+	private $isExistsNextPage;	// 次のページがあるかどうか
 	const THREAD_ID_LENGTH = 5;	// スレッドIDの長さ
 	
 	/**
@@ -54,6 +56,8 @@ class m_chachaMypageWidgetContainer extends m_chachaBaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		$act = $request->trimValueOf('act');
+		$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO, '1');				// ページ番号
+		if (empty($pageNo)) $pageNo = 1;
 		$postTicket = $request->trimValueOf('ticket');		// POST確認用
 		$memberId = $request->trimValueOf(self::URL_PARAM_MEMBER_ID);	// 会員ID
 		$message = $request->mobileTrimValueOf('message');		// 投稿メッセージ
@@ -121,9 +125,8 @@ class m_chachaMypageWidgetContainer extends m_chachaBaseWidgetContainer
 			$this->tmpl->addVar("thread_area", "avatar_image", $imageTag);		// 画像
 
 			// 投稿文を作成
-			$limit = $this->_configArray[self::CF_MESSAGE_COUNT_MYPAGE];		// 最大項目数
-			$page = 1;
-			$this->_db->getThreadByMemberId($this->_boardId, $memberId, $limit, $page, array($this, 'itemsLoop'));
+			$this->messageCount = $this->_configArray[self::CF_MESSAGE_COUNT_MYPAGE];		// 最大項目数
+			$this->_db->getThreadByMemberId($this->_boardId, $memberId, $this->messageCount, $pageNo, array($this, 'itemsLoop'), true);
 			
 			// 画面にデータを埋め込む
 			$this->tmpl->addVar("thread_area", "name", $this->convertToDispString($row['mb_name']));				// ユーザ名
@@ -153,6 +156,19 @@ class m_chachaMypageWidgetContainer extends m_chachaBaseWidgetContainer
 			$registName = 'ﾌﾟﾛﾌｨｰﾙ';
 			$this->tmpl->addVar("_widget", "regist_url", $registLink);
 			$this->tmpl->addVar("_widget", "regist_name", $registName);
+			
+			// ページ遷移用リンク
+			$pageLink = '';
+			if ($pageNo > 1){			// 前のページがあるとき
+				$foreLink = $this->convertUrlToHtmlEntity($this->getUrl($this->_currentPageUrl . '&' . self::URL_PARAM_MEMBER_ID . '=' . $memberId . '&page=' . ($pageNo -1), true));
+				$pageLink .= '<a href="' . $foreLink . '" accesskey="1">前へ[1]</a>';
+			}
+			if ($this->isExistsNextPage){	// 次のページがあるとき
+				if (!empty($pageLink)) $pageLink .= '&nbsp;&nbsp;';
+				$nextLink = $this->convertUrlToHtmlEntity($this->getUrl($this->_currentPageUrl . '&' . self::URL_PARAM_MEMBER_ID . '=' . $memberId . '&page=' . ($pageNo +1), true));
+				$pageLink .= '<a href="' . $nextLink . '" accesskey="2">次へ[2]</a>';
+			}
+			$this->tmpl->addVar("_widget", "page_link", $pageLink);
 		} else {
 			$this->setUserErrorMsg('会員IDが不正です');
 			
@@ -173,7 +189,11 @@ class m_chachaMypageWidgetContainer extends m_chachaBaseWidgetContainer
 	 */
 	function itemsLoop($index, $fetchedRow)
 	{
-		// ##### メッセージ部分を作成 #####
+		// 最大表示数を超えたときは終了
+		if ($index >= $this->messageCount){
+			$this->isExistsNextPage = true;				// 次のページあり
+			return false;
+		}
 		
 		// 日付作成
 		$weekDay = array('日', '月', '火', '水', '木', '金', '土');
