@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: lookup.inc.php 1095 2008-10-21 08:51:41Z fishbone $
+ * @version    SVN: $Id: lookup.inc.php 1601 2009-03-21 05:51:06Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -42,29 +42,17 @@ function plugin_lookup_convert()
 	$script = get_script_uri();
 	$postScript = $script . WikiParam::convQuery("?");
 	$ret = <<<EOD
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="plugin" value="lookup" />
   <input type="hidden" name="refer"  value="$s_page" />
   <input type="hidden" name="inter"  value="$interwiki" />
   <label for="_p_lookup_$id">$interwiki:</label>
   <input type="text" name="page" id="_p_lookup_$id" size="30" value="$default" />
-  <input type="submit" value="$button" />
+  <input type="submit" class="button" value="$button" />
  </div>
 </form>
 EOD;
-	/*$ret = <<<EOD
-<form action="$script" method="post">
- <div>
-  <input type="hidden" name="plugin" value="lookup" />
-  <input type="hidden" name="refer"  value="$s_page" />
-  <input type="hidden" name="inter"  value="$interwiki" />
-  <label for="_p_lookup_$id">$interwiki:</label>
-  <input type="text" name="page" id="_p_lookup_$id" size="30" value="$default" />
-  <input type="submit" value="$button" />
- </div>
-</form>
-EOD;*/
 	return $ret;
 }
 
